**This is a Libary for simplyfing storing data on disk with JSON**

To install this libary, do the following:

1. Download this entire github repositery and move it into folder, call it whatever you wnat
2. Change your directory to the folder, Example: the folder is called HelloWorld, do "cd HelloWorld"
3. After that, run this command.
```
pip install .
```
After that it should say you have sucessfully imported the package. Now you can 
import the package like the following


```python
import datasave
```
